coadd package
=============

Submodules
----------

coadd.coadd module
------------------

.. automodule:: coadd.coadd
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: coadd
   :members:
   :undoc-members:
   :show-inheritance:
